Learn R Programming

rts2 (version 0.10.2)

logLik.rtsFit: Extracts the log-likelihood from an rtsFit object

Description

Extracts the final log-likelihood value from an rtsFit object. Only returns a value for maximum likelihood model fits, otherwise it produces an error.

Usage

# S3 method for rtsFit
logLik(object, ...)

Value

An object of class logLik for maximum likelihood model fits, otherwise it returns an error.

Arguments

object

An rtsFit model fit.

...

Further arguments passed from other methods