Learn R Programming

rts2 (version 0.10.2)

print.rtsFit: Prints an rtsFit fit output

Description

Print method for class "rtsFit"

Usage

# S3 method for rtsFit
print(x, ...)

Value

No return value, called for side effects.

Arguments

x

an object of class "rtsFit"

...

Further arguments passed from other methods

Details

print.rtsFit tries to replicate the output of other regression functions, such as lm and lmer reporting parameters, standard errors, and z- and p- statistics for maximum likelihood esitmates, or posterior means, standard deviations and credible intervals for Bayesian models.