Learn R Programming

rts2 (version 0.10.2)

residuals.grid: Residuals method for a grid object

Description

Conditional raw or standardised residuals are returned for a stored rtsFit objects. If no prior model fit is stored, then an error is returned.

Usage

# S3 method for grid
residuals(object, type, ...)

Value

A matrix with number of columns corresponding to the number of MCMC samples.

Arguments

object

A grid object.

type

Either "standardized" or "raw"

...

Further arguments passed from other methods