Learn R Programming

rts2 (version 0.10.2)

residuals.rtsFit: Residuals method for a rtsFit object

Description

Conditional raw or standardised residuals for rstFit objects. The residuals are limited to conditional raw or standardised residuals currently to avoid copying the often large amount of model data stored in the associated grid object.

Usage

# S3 method for rtsFit
residuals(object, type, ...)

Value

A matrix with number of columns corresponding to the number of MCMC samples.

Arguments

object

A rtsFit object.

type

Either "standardized" or "raw"

...

Further arguments passed from other methods