Learn R Programming

rts2 (version 0.10.2)

summary.rtsFit: Summary method for class "rtsFit"

Description

Summary method for class "rtsFit"

Usage

# S3 method for rtsFit
summary(object, ...)

Value

An rtsFitSummary object

Arguments

object

an object of class "rtsFit" as a result of a call to lgcp_ml() or lgcp_bayes()

...

Further arguments passed from other methods

Details

The summary methods aims to replicate the output of other regression model fitting functions and reports central point estimates, relevant test statistics, and uncertainty intervals. In addition, the returned summary object will also include time period specific relative risk and incidence predictions.