Extracts the final log-likelihood value from an rtsFit object. Only returns a value for maximum likelihood model fits, otherwise it produces an error.
# S3 method for rtsFit
logLik(object, ...)An object of class logLik for maximum likelihood model fits, otherwise it returns an error.
An rtsFit model fit.
Further arguments passed from other methods