Print method for class "rtsFit"
# S3 method for rtsFit
print(x, ...)No return value, called for side effects.
an object of class "rtsFit"
Further arguments passed from other methods
print.rtsFit tries to replicate the output of other regression functions, such
as lm and lmer reporting parameters, standard errors, and z- and p- statistics for maximum
likelihood esitmates, or posterior means, standard deviations and credible intervals for
Bayesian models.