grid objectConditional raw or standardised residuals are returned for a stored rtsFit objects. If no prior model fit is stored,
then an error is returned.
# S3 method for grid
residuals(object, type, ...)A matrix with number of columns corresponding to the number of MCMC samples.
A grid object.
Either "standardized" or "raw"
Further arguments passed from other methods