rtsFit objectConditional raw or standardised residuals for rstFit objects. The residuals are limited to conditional raw or standardised
residuals currently to avoid copying the often large amount of model data stored in the associated grid object.
# S3 method for rtsFit
residuals(object, type, ...)A matrix with number of columns corresponding to the number of MCMC samples.
A rtsFit object.
Either "standardized" or "raw"
Further arguments passed from other methods