Summary method for class "rtsFit"
# S3 method for rtsFit
summary(object, ...)An rtsFitSummary object
an object of class "rtsFit" as a result of a call to lgcp_ml() or lgcp_bayes()
Further arguments passed from other methods
The summary methods aims to replicate the output of other regression model fitting functions and reports central point estimates, relevant test statistics, and uncertainty intervals. In addition, the returned summary object will also include time period specific relative risk and incidence predictions.